==> haskell-cairo-0.13.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cairo
version: 0.13.3.1
id: cairo-0.13.3.1-B8SWhbrAJssFhnsoNQJ69I
key: cairo-0.13.3.1-B8SWhbrAJssFhnsoNQJ69I
license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Matrix
    Graphics.Rendering.Cairo.Types Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
                Graphics.Rendering.Cairo.Internal.Region
abi: ecab8c7aac4f3586ab0dbfd3d29c19fb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cairo-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cairo-0.13.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cairo-0.13.3.1
hs-libraries: HScairo-0.13.3.1-B8SWhbrAJssFhnsoNQJ69I
extra-libraries:
    z cairo
include-dirs: /usr/include/cairo /usr/include/pixman-1
              /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
              /usr/include/glib-2.0 /usr/lib/glib-2.0/include /usr/include/libdrm
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html: /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cairo-0.13.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cairo
version: 0.13.3.1
id: cairo-0.13.3.1-2aGPO8ZCviBEichAQxduNY
key: cairo-0.13.3.1-2aGPO8ZCviBEichAQxduNY
license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Matrix
    Graphics.Rendering.Cairo.Types Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
                Graphics.Rendering.Cairo.Internal.Region
abi: 4ecc95f2d7f9b12434e4121c6d91a178
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cairo-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cairo-0.13.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cairo-0.13.3.1
hs-libraries: HScairo-0.13.3.1-2aGPO8ZCviBEichAQxduNY
extra-libraries:
    z cairo
include-dirs: /usr/include/cairo /usr/include/pixman-1
              /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
              /usr/include/glib-2.0 /usr/lib/glib-2.0/include /usr/include/libdrm
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html: /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
